#
# spec file for package massif-visualizer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define qt6_version 6.6.0

%bcond_without released
Name:           massif-visualizer
Version:        24.08.3
Release:        1.1
Summary:        Visualizer for output generated by Valgrind's massif tool
License:        LGPL-2.0-only
URL:            https://apps.kde.org/massif-visualizer
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KChart6) >= 3.0.0
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KGraphViewerPart) >= 2.5.0
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kgraphviewer >= 2.5.0
Recommends:     valgrind

%description
Massif Visualizer is a tool that visualizes massif data.
You run your application in Valgrind with --tool=massif and then open the
generated massif.out.pid file in the visualizer.
Gzip or Bzip2 compressed massif files can also be opened transparently.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%suse_update_desktop_file org.kde.massif-visualizer Debugger

%find_lang massif-visualizer %{name}.lang

%files lang -f %{name}.lang

%files
%license COPYING
%doc AUTHORS README
%{_kf6_applicationsdir}/org.kde.massif-visualizer.desktop
%{_kf6_appstreamdir}/org.kde.massif-visualizer.appdata.xml
%{_kf6_bindir}/massif-visualizer
%{_kf6_configkcfgdir}/massif-visualizer-settings.kcfg
%{_kf6_iconsdir}/hicolor/scalable/apps/massif-visualizer.svg
%{_kf6_sharedir}/massif-visualizer/
%{_kf6_sharedir}/mime/packages/massif.xml

%changelog
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- massif-visualizer is now released with KDE gear applications
* Thu May  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.8.0:
  https://blogs.kde.org/2024/05/08/massif-visualizer-0.8.0-released/
  * Port to Qt6 and KF6
  * General code modernization
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Fri Sep  8 2017 wbauer@tmo.at
- Update to 0.7.0
  * http://jriddell.org/2017/09/07/massif-visualizer-0-7-0-released/
- Drop office-chart-area.png, a proper application icon is
  included/installed now
* Sun Nov 30 2014 hrvoje.senjan@gmail.com
- Update to 0.4.0 final
  * For more details, please see
    http://milianw.de/blog/massif-visualizer-04-and-kgraphviewer-22-released
* Wed Nov 12 2014 cgiboudeaux@gmx.com
- Replace the GIT snapshot with massif-visualizer 0.4Beta
* Tue Jan 28 2014 cgiboudeaux@gmx.com
- Translations update.
* Mon Oct 14 2013 cgiboudeaux@gmx.com
- Update translations
* Thu Mar 17 2011 cgiboudeaux@gmx.com
- Add massif-visualizer.
  Visualizer for Valgrind Massif data files.
